Crate kcr_external_secrets_io

Crate kcr_external_secrets_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the external-secrets.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

external-secrets.io/v1

  • ClusterExternalSecret
  • ClusterSecretStore
  • ExternalSecret
  • SecretStore

external-secrets.io/v1alpha1

  • ClusterPushSecret
  • ClusterSecretStore
  • ExternalSecret
  • PushSecret
  • SecretStore

external-secrets.io/v1beta1

  • ClusterExternalSecret
  • ClusterSecretStore
  • ExternalSecret
  • SecretStore

Modules

v1
v1alpha1
v1beta1